% Basic RBC Model with preference shock and TFP shock and with capital utilization
%
% Copywrite (C) Written by Bo Zhang, zhangbo@swufe.edu.cn
% 
%----------------------------------------------------------------
% 0. Housekeeping (close all graphic windows)
%----------------------------------------------------------------

close all;

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------
var y n k c lamda e d i a z;
varexo e_a e_z;
parameters alpha beta v delta phie gamma;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------
% 
% U(c,n,z) = exp(z)*log(c) -chi*n^(1+v)/(1+v);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
alpha=0.33;
beta=0.99;
v=1;
delta=0.025;
gamma=1.2;
phie=0.0351;

%----------------------------------------------------------------
% 3. Model
%----------------------------------------------------------------
model(linear); 

//(1) Consumption/leisure choice 
v*n=lamda+y-n;

//(2) Euler equation
z-c=lamda;
lamda=lamda(+1)+beta*((1/beta+delta-1)*(y(+1)-k)-delta*d(+1));

//(3) Foc w.r.t. capital utilization rate
y=k(-1)+gamma*e;

//(4) capital depreciation
delta*d=phie*e;

//(5) Production function
y=a+alpha*(e+k(-1))+(1-alpha)*n;

//(6) Resource constraint
y=alpha*delta/phie*i+(1-alpha*delta/phie)*c;

// (7) Investment
k=(1-delta)*k(-1)-delta*d+delta*i;

//(8) Technology shock
a=0.95*a(-1)+e_a;

// (9) IST shock
z=0.8*z(-1)+e_z;
end;



steady;
check;


%----------------------------------------------------------------
% 4. Computation
%----------------------------------------------------------------

shocks;

var e_a=1^2;
var e_z=1^2;
end;
stoch_simul(irf=40,order=1)c n i e;