
function [gx, gu, Hxx, Hxu, Huu] = Pitfall_model

%Inputs: none
%
%Output: Analytical first derivatives of the constraint function g and
%second derivatives of the Hamiltonian H
%
%Calls: anal_derivative.m 
%

%Define parameters
syms ALFA BETTA rho1 rho2

%Define model variables
syms c k a1 a2

%Define the vector of controls u, and states x
u = c; % Column control vector 

x = [a1; a2; k];  %Column state vector
nx =length(x);  %number of states

%Define the vector of Lagrange multipliers for the state x
syms lambdaSS [nx 1];
  
%Define objective function
%c = exp(a)*k^ALFA*n^(1-ALFA)-Inv; %Consumption
f = log(c); 

%Define constraints

g1 = rho1*a1; %Motion of technology shock 1
g2 = rho2*a2; %Motion of technology shock 2
g3 = exp(a1+a2)*k^ALFA- c; %Motion of capital
g = [g1; g2; g3];

%Compute analytical derivatives of f
[gx, gu, Hxx, Hxu,Huu] = anal_derivative(f, g, x, u, lambdaSS);
