
function [gx, gu, Hxx, Hxu, Huu] = RBCIST_model;

%Inputs: none
%
%Output: Analytical first derivatives of the constraint function g and
%second derivatives of the Hamiltonian H
%
%Calls: anal_derivative.m 
%

%Define parameters
syms chi nu delta ALFA BETTA rho rho_z phi gama
%Define model variables
syms c k n Inv e a z

%Define the vector of controls u, and states x
u = [c; n; e]; % Column control vector, endgenous capital utilization 
%u =[c;n];  %Exogenous capital utilization with e =1
x = [z; a; k];  %Column state vector
nx =length(x);  %number of states

%Define the vector of Lagrange multipliers for the state x
syms lambdaSS [nx 1];
  
%Define objective function

f = log(c) - chi*n^(1+nu)/(1+nu); 

%Define constraints
g1 = rho_z*z;
g2 = rho*a; %Motion of technology shock
g3 = (1-delta)*k + exp(z)*(exp(a)*(e*k)^ALFA*n^(1-ALFA)- c) - phi*k*(e^gama-1)/gama; %Motion of capital

g = [g1; g2; g3];

%Compute analytical derivatives of f
[gx, gu, Hxx, Hxu,Huu] = anal_derivative(f, g, x, u, lambdaSS);
