%Solving a simple RBC model with preference and technology shocks
%State vector x(t) =(a(t),K(t),y_1t,y_2t,y_3t)', control vector u(t)=(C(t),N(t))'
%Call codes RBC0_model.m and RBC0_model_ss.m


clear all;
close all;
tic
flag = 0; % flag = 0 means endogenous capital utilization; otherwise exogenous utilization e = 1.

[gx, gu, Hxx, Hxu, Huu] = RBCNews_model;

%Numerical Evaluation
%Steady State and Parameter Values
[ALFA,BETTA,delta,chi,nu, phi, gama, rho, sigma,sigma_news, c,k,n,Inv,e, a,...
    y1,y2,y3, lambdaSS1,lambdaSS2,lambdaSS3,lambdaSS4, lambdaSS5] = RBCNews_model_ss;

%Obtain numerical derivatives of f
num_derivative

%% Solution under Full information 
%% Using MWY(2022) Notation

Q = -nHxx/2;
S = -nHxu/2;
R = -nHuu/2;
A = ngx;
B = ngu;

nx =size(Q,1);

P0 = eye(nx,nx);
[P,F,err,iter] = LQG(A,B,S,Q,R,BETTA,P0); % Call a function to compute Riccati equation
disp('Linear decision rule coefficents: ')
% u = -F*\hat{x}; 
F

%RI solution
L = zeros(5,2);
L(1,1) = sigma;
L(5,2) = sigma_news;
W = L*L';

lambda=  0.005; %lambdav(1);
Omega = F'*(R+ BETTA*B'*P*B)*F;

    Sigma_pr0 = A*A'+W; %Initial guess of optimal prior covariance matrix 
    
    Theta0 = Omega; % Initial guess of dynamic benefit matrix
    [SigmaSS, Sigma_prSS, ThetaSS, LambdaSS] = RI_SS_FOC(lambda,BETTA,A,W,Omega, Theta0,Sigma_pr0); 

[C,V,r] = RI_SIG(SigmaSS,Sigma_prSS,ThetaSS,lambda); %Compute signal structure

display('Steady state signal structure: [C V], Sigma')
[C,V]
SigmaSS


%impulse responses to one standard deviation innovation shock

Period = 40;
[X_full, u_full, X, u] = RI_IRF3(A,B,F,L, Period, SigmaSS, C, V);

toc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Transform to log linear responses
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure;
time =1:Period;
%set(gcf,'defaulttextinterpreter','latex')
subplot(2,4,1)
plot(time,100*u_full(1,:,1)/c,'LineWidth',1.5);
    hold on
plot(time,100*u(1,:,1)/c,'--','LineWidth',1.5);
title(['C_t to TFP shock'])
%legend('Full Info','RI')
ax = gca;
ax.FontSize = 7;
ax.TitleFontSizeMultiplier = 0.8;

subplot(2,4,2)
plot(time,100*u_full(2,:,1)/n,'LineWidth',1.5);
    hold on
plot(time,100*u(2,:,1)/n,'--','LineWidth',1.5);
title('N_t to TFP shock')
%legend('Full Info','RI')
ax = gca;
ax.FontSize = 7;
ax.TitleFontSizeMultiplier = 0.8;

%Compute I_t IRF

if flag ==0
    %Full information case
    Yt_full = k^ALFA*n^(1-ALFA)*X_full(1,:,1) + ALFA*k^(ALFA-1)*n^(1-ALFA)*X_full(2,:,1)...
    + ALFA*k^ALFA*n^(1-ALFA)*u_full(3,:,1) + (1-ALFA)*k^ALFA*n^(-ALFA)*u_full(2,:,1);   
   %RI case
    Yt = k^ALFA*n^(1-ALFA)*X(1,:,1) + ALFA*k^(ALFA-1)*n^(1-ALFA)*X(2,:,1)...
        +(1-ALFA)*k^ALFA*n^(-ALFA)*u(2,:,1); 
else
    %Full information case
    Yt_full = k^ALFA*n^(1-ALFA)*X_full(1,:,1) + ALFA*k^(ALFA-1)*n^(1-ALFA)*X_full(2,:,1)...
         + (1-ALFA)*k^ALFA*n^(-ALFA)*u_full(2,:,1);   
   %RI case
    Yt = k^ALFA*n^(1-ALFA)*X(1,:,1) + ALFA*k^(ALFA-1)*n^(1-ALFA)*X(2,:,1)...
        +(1-ALFA)*k^ALFA*n^(-ALFA)*u(2,:,1); 
end

   ItFull_TFP = Yt_full - u_full(1,:,1);
   ItRI_TFP =  Yt - u(1,:,1); 

subplot(2,4,3)
plot(time,100*ItFull_TFP/Inv, 'LineWidth',1.5);
    hold on
plot(time,100*ItRI_TFP/Inv,'--','LineWidth',1.5);
title('I_t to TFP shock')
%legend('Full Info','RI')
ax = gca;
ax.FontSize = 7;
ax.TitleFontSizeMultiplier = 0.8;

subplot(2,4,4)
if flag ==0 %Variable capital utilization
    plot(time,100*u_full(3,:,1), 'LineWidth',1.5);
        hold on
    plot(time,100*u(3,:,1),'--','LineWidth',1.5);
else % Fixed capital utilization
    plot(time, ones(1,Period), 'LineWidth', 1.5);    
end
title('e_t to TFP shock')
%legend('Full Info','RI')
ax = gca;
ax.FontSize = 7;
ax.TitleFontSizeMultiplier = 0.8;

subplot(2,4,5)
plot(time,100*u_full(1,:,2)/c,'LineWidth',1.5);
    hold on
plot(time,100*u(1,:,2)/c,'--','LineWidth',1.5);
xlabel('time')
%legend('Full Info','RI')
title('C_t to news shock')
ax = gca;
ax.FontSize = 7;
ax.TitleFontSizeMultiplier = 0.8;

subplot(2,4,6)
plot(time,100*u_full(2,:,2)/n,'LineWidth',1.5);
    hold on
plot(time,100*u(2,:,2)/n,'--','LineWidth',1.5);
xlabel('time')
%legend('Full Info','RI')
title('N_t to news shock')
ax = gca;
ax.FontSize = 7;
ax.TitleFontSizeMultiplier = 0.8;

%I_t to news shock
if flag ==0
%Full information
    Yt_full = k^ALFA*n^(1-ALFA)*X_full(1,:,2) + ALFA*k^(ALFA-1)*n^(1-ALFA)*X_full(2,:,2)...
        + ALFA*k^ALFA*n^(1-ALFA)*u_full(3,:,2) + (1-ALFA)*k^ALFA*n^(-ALFA)*u_full(2,:,2);
%RI case
    Yt = k^ALFA*n^(1-ALFA)*X(1,:,2) + ALFA*k^(ALFA-1)*n^(1-ALFA)*X(2,:,2)...
        + ALFA*k^ALFA*n^(1-ALFA)*u(3,:,2)+(1-ALFA)*k^ALFA*n^(-ALFA)*u(2,:,2); 
else
%Full information
    Yt_full = k^ALFA*n^(1-ALFA)*X_full(1,:,2) + ALFA*k^(ALFA-1)*n^(1-ALFA)*X_full(2,:,2)...
         + (1-ALFA)*k^ALFA*n^(-ALFA)*u_full(2,:,2);
%RI case
    Yt = k^ALFA*n^(1-ALFA)*X(1,:,2) + ALFA*k^(ALFA-1)*n^(1-ALFA)*X(2,:,2)...
       +(1-ALFA)*k^ALFA*n^(-ALFA)*u(2,:,2);  
end

ItFull_news = Yt_full - u_full(1,:,2);
ItRI_news =  Yt - u(1,:,2);

subplot(2,4,7)
plot(time,100*ItFull_news/Inv,'LineWidth',1.5);
    hold on
plot(time,100*ItRI_news/Inv,'--','LineWidth',1.5);
xlabel('time')

title('I_t to news shock')
ax = gca;
ax.FontSize = 7;
ax.TitleFontSizeMultiplier = 0.8;


subplot(2,4,8) %capital utilization
if flag ==0
    plot(time,100*u_full(3,:,2), 'LineWidth',1.5);
        hold on
    plot(time,100*u(3,:,2),'--','LineWidth',1.5);
  else
    plot(time, ones(1,Period), 'LineWidth', 1.5);    
end

title('e_t to news shock')

lgd = legend('Full Info','RI')
lgd.FontSize = 4;
ax = gca;
ax.FontSize = 7;
ax.TitleFontSizeMultiplier = 0.8;

print -depsc FigRBCNews.eps