
function [gx, gu, Hxx, Hxu, Huu] = RBCNews_model

%Inputs: none
%
%Output: Analytical first derivatives of the constraint function g and
%second derivatives of the Hamiltonian H
%
%Calls: anal_derivative.m 
%

%Define parameters
syms chi nu delta ALFA BETTA rho phi gama
%Define model variables
syms c k n Inv e a y1 y2 y3

%Define the vector of controls u, and states x
u = [c; n; e]; % Column control vector, variable capital utilization 
%u = [c;n]; % fixed capital utilization
x = [a; k; y1; y2; y3];  %Column state vector
nx =length(x);  %number of states

%Define the vector of Lagrange multipliers for the state x
syms lambdaSS [nx 1];
  
%Define objective function

f = log(c) - chi*n^(1+nu)/(1+nu); 

%Define constraints

g1 = rho*a+y1; %Motion of technology shock
g2 = (1-delta)*k + exp(a)*(e*k)^ALFA*n^(1-ALFA)- c - phi*k*(e^gama-1)/gama; %Motion of capital
g3 = y2;
g4 = y3;
g5 = 0;
g = [g1; g2; g3; g4; g5];

%Compute analytical derivatives of f
[gx, gu, Hxx, Hxu,Huu] = anal_derivative(f, g, x, u, lambdaSS);
