
function [gx, gu, Hxx, Hxu, Huu] = RBC_model;

%Inputs: none
%
%Output: Analytical first derivatives of the constraint function g and
%second derivatives of the Hamiltonian H
%
%Calls: anal_derivative.m 
%

%Define parameters
syms chi nu SIG delta ALFA BETTA rho rho_z

%Define model variables
syms c k n Inv a z 

%Define the vector of controls u, and states x
u = [Inv; n]; % Column control vector 
x = [z; a; k];  %Column state vector
nx =length(x);  %number of states

%Define the vector of Lagrange multipliers for the state x
syms lambdaSS [nx 1];
  
%Define objective function
c = exp(a)*k^ALFA*n^(1-ALFA)-Inv; %Consumption
f = exp(z)*(log(c) - chi*n^(1+nu)/(1+nu)); 

%Define constraints

g1 = rho_z*z; %Motion of preference shock
g2 = rho*a; %Motion of technology shock
g3 = (1-delta)*k + Inv; %Motion of capital
g = [g1; g2; g3];

%Compute analytical derivatives of f
[gx, gu, Hxx, Hxu,Huu] = anal_derivative(f, g, x, u, lambdaSS);
